/* Broadcom NetXtreme-C/E network driver.
 *
 * Copyright (c) 2014-2016 Broadcom Corporation
 * Copyright (c) 2016-2018 Broadcom Limited
 * Copyright (c) 2018-2022 Broadcom Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation.
 */

#ifndef BNXT_DBR_H
#define BNXT_DBR_H

/* 32-bit XORSHIFT generator.  Seed must not be zero. */
static inline u32 xorshift(u32 *state)
{
	u32 seed = *state;

	seed ^= seed << 13;
	seed ^= seed >> 17;
	seed ^= seed << 5;

	*state = seed;
	return seed;
}

static inline u16 rnd(u32 *state, uint16_t range)
{
	/* range must be a power of 2 - 1 */
	return (xorshift(state) & range);
}

#define BNXT_DB_FIFO_ROOM_MASK      0x1fff8000
#define BNXT_DB_FIFO_ROOM_SHIFT     15
#define BNXT_MAX_FIFO_DEPTH         0x2c00

#define BNXT_DB_PACING_ALGO_THRESHOLD	250
#define BNXT_DEFAULT_PACING_PROBABILITY 0xFFFF

static inline int __get_fifo_occupancy(struct bnxt *bp)
{
	struct bnxt_dbr *dbr = &bp->dbr;
	u32 val;

	val = readl(bp->bar0 + dbr->db_fifo_reg_off);
	return BNXT_MAX_FIFO_DEPTH -
		((val & BNXT_DB_FIFO_ROOM_MASK) >>
		 BNXT_DB_FIFO_ROOM_SHIFT);
}

/* Caller make sure that the pacing is enabled or not */
static inline void bnxt_do_pacing(struct bnxt *bp, u32 *seed, u32 pacing_th, u32 pacing_prob)
{
	struct bnxt_dbr *dbr = &bp->dbr;
	u32 pace_time = 1;
	u32 retry = 10;

	if (!dbr->pacing_enable)
		return;

	if (rnd(seed, 0xFFFF) < pacing_prob) {
		while (__get_fifo_occupancy(bp) > pacing_th &&
		       retry--) {
			u32 us_delay;

			us_delay = rnd(seed, pace_time - 1);
			if (us_delay)
				udelay(us_delay);
			/* pacing delay time capped at 128 us */
			pace_time = min_t(u16, pace_time * 2, 128);
		}
	}
}

static inline void bnxt_do_pacing_default(struct bnxt *bp, u32 *seed)
{
	bnxt_do_pacing(bp, seed, BNXT_DB_PACING_ALGO_THRESHOLD,
		       BNXT_DEFAULT_PACING_PROBABILITY);
}
#endif
